@@ -32,20 +32,36 @@ GroupManager::GroupManager(QObject *parent)
             m_user = KUser().loginName();
             const QStringList groups = KUser(m_user).groupNames();
 
-            // First check to see if the path where user shares will be exported exists
-            if (path.isEmpty() || !info.exists()) {
+            if (path.isEmpty()) {
+                m_errorText = xi18nc("@info:status", "Your Samba installation appears to be broken.");
+                Q_EMIT errorTextChanged();
+                const auto err = proc->readAllStandardError().trimmed();
+                if (err.isEmpty()) {
+                    m_errorExplanation = xi18nc("@info:status", "This error is caused by your distribution not setting up Samba sharing properly. Please file a bug with your distribution or check your distribution's documentation on setting up Samba sharing.");
+                } else {
+                    m_errorExplanation = xi18nc("@info:status", "This error is caused by your distribution not setting up Samba sharing properly. Please file a bug with your distribution or check your distribution's documentation on setting up Samba sharing. Error:<nl/><message>%1</message>", QString::fromUtf8(err));
+                }
+                Q_EMIT errorExplanationChanged();
+            }
+
+            // Check to see if the path where user shares will be exported exists
+            else if (!info.exists()) {
                 m_errorText = xi18nc("@info:status", "This folder can't be shared because <filename>%1</filename> does not exist.", path);
                 Q_EMIT errorTextChanged();
-                m_errorExplanation = xi18nc("@info:status", "This error is caused by your distro not setting up Samba sharing properly. You can fix it yourself by creating that folder manually. Then close and re-open this window.");
+                m_errorExplanation = xi18nc("@info:status", "This error is caused by your distribution not setting up Samba sharing properly. You can fix it yourself by creating that folder manually. Then close and re-open this window.");
                 Q_EMIT errorExplanationChanged();
                 // TODO: define a helpfulAction that creates the folder
             }
 
             // Now see if the group is set to something valid
-            else if (m_targetGroup == QLatin1String("root")) {
-                m_errorText = xi18nc("@info:status", "This folder can't be shared because <filename>%1</filename> has its group owner inappropriately set to <resource>%2</resource>.", path, m_targetGroup);
+            // Keep this condition in sync with the one in authhelper.cpp
+            else if (!m_targetGroup.contains(QLatin1String("samba"))
+                     || m_targetGroup.contains(QLatin1String("admin"))
+                     || m_targetGroup.contains(QLatin1String("root"))
+                    ) {
+                m_errorText = xi18nc("@info:status", "This folder can't be shared because <filename>%1</filename> has its group owner inappropriately set to <resource>%2</resource>, which is not allowed.", path, m_targetGroup);
                 Q_EMIT errorTextChanged();
-                m_errorExplanation = xi18nc("@info:status", "This error is caused by your distro not setting up Samba sharing properly. You can fix it yourself by changing that folder's group owner to <resource>usershares</resource> and making yourself a member of that group. Then restart the system.");
+                m_errorExplanation = xi18nc("@info:status", "This error is caused by your distribution not setting up Samba sharing properly. You can fix it yourself by changing that folder's group owner to <resource>sambashares</resource> and making yourself a member of that group. Then restart the system.");
                 Q_EMIT errorExplanationChanged();
                 // TODO: define a helpfulAction that creates the group and applies it to the folder
             }
@@ -96,8 +112,8 @@ void GroupManager::performHelpfulAction()
             action.addArgument(QStringLiteral("user"), user);
             action.addArgument(QStringLiteral("group"), group);
             action.setDetailsV2({{KAuth::Action::AuthDetail::DetailMessage,
-                                i18nc("@label kauth action description %1 is a username %2 a group name",
-                                        "Adding user '%1' to group '%2' so they may configure Samba user shares",
+                                xi18nc("@label kauth action description %1 is a username %2 a group name",
+                                        "Adding user <resource>%1</resource> to group <resource>%2</resource> so they may configure Samba user shares",
                                         user,
                                         group) }
             });
@@ -108,7 +124,7 @@ void GroupManager::performHelpfulAction()
                     QString helpfulActionErrorText = job->errorString();
                     if (helpfulActionErrorText.isEmpty()) {
                         // unknown error :(
-                        helpfulActionErrorText = i18nc("@info", "Failed to make user <resource>%1<resource> a member of group <resource>%2<resource>", user, group);
+                        helpfulActionErrorText = xi18nc("@info", "Failed to make user <resource>%1</resource> a member of group <resource>%2</resource>", user, group);
                     }
                     Q_EMIT helpfulActionError(helpfulActionErrorText);
                     return;
